@@ -2,11 +2,11 @@
 if(require(testthat)){
 
   test_that("tests for some arguments in forecast 1", {
-    library(forecast)
+
     forecast(ARml(AirPassengers, caret_method = "lm", max_lag = 12, K=5),
              h = 2) -> fc
-    values <- round(c(fc$mean))
-    expect_that(values, equals(c(454, 434)))
+    values <- as.numeric(ceiling(c(fc$mean)))
+    expect_equal(values, c(459, 429), tolerance = 1)
 
   })
 }
@@ -16,12 +16,12 @@ if(require(testthat)){
 if(require(testthat)){
 
   test_that("tests for some arguments in forecast 2", {
-    library(forecast)
+
     ARml(AirPassengers, caret_method = "lm", max_lag = 10,
          xreg = forecast::seasonaldummy(AirPassengers), seasonal = F) -> fit
     forecast(fit, h = 2, xreg = forecast::seasonaldummy(AirPassengers, h = 2)) -> fc
-    values <- round(c(fc$mean))
-    expect_that(values, equals(c(447, 430)))
+    values <- as.numeric(ceiling(c(fc$mean)))
+    expect_equal(values, c(446, 445), tolerance = 1)
 
   })
 }
@@ -30,11 +30,11 @@ if(require(testthat)){
 if(require(testthat)){
 
   test_that("tests for some arguments in forecast 3", {
-    library(forecast)
+
     forecast(ARml(AirPassengers, caret_method = "lm", max_lag = 12,
                   seasonal = F), h = 2) -> fc
-    values <- round(c(fc$mean))
-    expect_that(values, equals(c(461, 433)))
+    values <- as.numeric(ceiling(c(fc$mean)))
+    expect_equal(values, c(465, 429), tolerance = 1)
 
   })
 }
