@@ -7,7 +7,7 @@ if(require(testthat)){
     expect_that(result, equals(c("spikeslab", "bagEarth", "bagEarthGCV", "blasso",
                                  "cforest", "earth","extraTrees", "gbm_h2o", "glmStepAIC",
                                  "parRF", "qrf", "Rborist", "rf", "rqlasso", "rqnc",
-                                 "spikeslab", "xgbDART", "xgbLinear", "ranger", "cubist",
+                                 "xgbDART", "xgbLinear", "ranger", "cubist",
                                  "svmLinear", "enet", "bridge", "glmboost", "ridge",
                                  "lasso", "relaxo", "M5Rules", "M5", "lm", "gaussprLinear",
                                  "glm", "glmnet", "pcr", "ppr", "foba", "gbm", "svmLinear2",
